bayespy.utils.misc
==================

.. automodule:: bayespy.utils.misc

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree: generated/
   
      T
      add_axes
      add_leading_axes
      add_trailing_axes
      array_to_scalar
      atleast_nd
      axes_to_collapse
      block_banded
      broadcasted_shape
      broadcasted_shape_from_arrays
      broadcasting_multiplier
      ceildiv
      check_gradient
      chol
      chol_inv
      chol_logdet
      chol_solve
      cholesky
      composite_function
      diag
      diagonal
      dist_haversine
      first
      gaussian_logpdf
      get_diag
      grid
      identity
      is_callable
      is_numeric
      is_shape_subset
      is_string
      isinteger
      kalman_filter
      logdet_chol
      logsumexp
      m_digamma
      m_dot
      m_outer
      m_solve_triangular
      make_equal_length
      make_equal_ndim
      mean
      moveaxis
      multidigamma
      multiply_shapes
      nans
      nested_iterator
      remove_whitespace
      repeat_to_shape
      rmse
      rts_smoother
      safe_indices
      squeeze
      squeeze_to_dim
      sum_multiply
      sum_multiply_to_plates
      sum_product
      sum_to_dim
      sum_to_shape
      symm
      tempfile
      trues
      unique
      vb_optimize
      vb_optimize_nodes
      write_to_hdf5
      zipper_merge
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree: generated/
   
      CholeskyDense
      CholeskySparse
      TestCase
   
   

   
   
   